Under-sampling Samplers — imbalanced-ensemble 0.1.0 documentation

# Under-sampling Samplers

The `imbalanced_ensemble.sampler.under_sampling` submodule contains methods to under-sample a dataset.

`ClusterCentroids`(**kwargs) | Undersample by generating centroids based on clustering methods.
`RandomUnderSampler`(**kwargs) | Class to perform random under-sampling.
`InstanceHardnessThreshold`(**kwargs) | Undersample based on the instance hardness threshold.
`NearMiss`(**kwargs) | Class to perform under-sampling based on NearMiss methods.
`TomekLinks`(**kwargs) | Under-sampling by removing Tomek’s links.
`EditedNearestNeighbours`(**kwargs) | Undersample based on the edited nearest neighbour method.
`RepeatedEditedNearestNeighbours`(**kwargs) | Undersample based on the repeated edited nearest neighbour method.
`AllKNN`(**kwargs) | Undersample based on the AllKNN method.
`OneSidedSelection`(**kwargs) | Class to perform under-sampling based on one-sided selection method.
`CondensedNearestNeighbour`(**kwargs) | Undersample based on the condensed nearest neighbour method.
`NeighbourhoodCleaningRule`(**kwargs) | Undersample based on the neighbourhood cleaning rule.
`BalanceCascadeUnderSampler`(**kwargs) | Class to perform under-sampling for BalanceCascade in [R4d2584dbf2bf-1].
`SelfPacedUnderSampler`(**kwargs) | Class to perform self-paced under-sampling in [R58fe15894bd9-1].